from django.contrib import admin

from .models import Mail


class MailAdmin(admin.ModelAdmin):
    search_fields = ('mail',)
    list_display = ('__str__', 'mail', 'is_send', 'send_at', 'event')


admin.site.register(Mail, MailAdmin)



import logging
from datetime import datetime, timedelta
from django.db import models
from django.core.mail import EmailMultiAlternatives
from django.conf import settings

from . import context


CRON_MINUTE = context.DS_CRON_HOUR * 60
logger = logging.getLogger('django_solar')


class Notification(models.Model):
    is_send = models.BooleanField(default=False)
    send_at = models.DateTimeField(default=datetime.now)
    event = models.CharField(default='', max_length=100)

    class Meta:
        abstract = True

    @property
    def is_time_to_send(self):
        minutes = CRON_MINUTE / 2
        date_now = datetime.now()
        date_prev = date_now - timedelta(minutes=minutes)
        date_next = date_now + timedelta(hours=minutes)

        logger.debug('\nNow: %s\nAt: %s\nNext: %s\n' % (
            date_prev,
            self.send_at,
            date_next
        ))

        if date_prev < self.send_at < date_next:
            logger.debug('Notification have to be send')
            return True
        logger.debug('Notification is not ready to be send')
        return False

    def send(self):
        self.is_send = True
        self.save()


class Mail(Notification):
    mail = models.EmailField(default=None, null=True)
    subject = models.CharField(default='', max_length=100)
    html = models.TextField(default=None)
    text = models.TextField(default='')
    from_mail = models.CharField(
        default=settings.DEFAULT_FROM_EMAIL,
        max_length=100
    )

    def __str__(self):
        return '%s at %s (%s)' % (
            'Send' if self.is_send else 'Not Send',
            str(self.send_at),
            self.mail
        )

    def send(self):
        if self.is_time_to_send:
            if context.DS_SEND_MAIL:
                msg = EmailMultiAlternatives(
                    self.subject,
                    self.text,
                    self.from_mail,
                    [self.mail]
                )
                if self.html:
                    msg.attach_alternative(self.html, "text/html")
                msg.send()
            return super().send()



import importlib
from django.core.management.base import BaseCommand
from django_solar.models import Mail
from django_solar import context


def import_from_string(val):
    """
    Attempt to import a class from a string representation.
    From: django-rest-framework
    """
    try:
        # Nod to tastypie's use of importlib.
        parts = val.split('.')
        module_path, class_name = '.'.join(parts[:-1]), parts[-1]
        module = importlib.import_module(module_path)
        return getattr(module, class_name)
    except ImportError as e:
        msg = "Could not import '%s' for setting. %s: %s." % (
            val, e.__class__.__name__, e
        )
        raise ImportError(msg)


class Command(BaseCommand):

    def handle(self, *args, **options):
        # Manage Event
        if context.DS_EVENT_MANAGER:
            manager = import_from_string(context.DS_EVENT_MANAGER)()
            for event_function in manager.get_event_functions():
                event_function()

        #  Send Email Notifications
        emails = Mail.objects.filter(is_send=False)
        for email in emails:
            email.send()



from django.contrib.auth.models import Group, User
from django.core.management.base import BaseCommand


class Command(BaseCommand):

    def handle(self, *args, **options):
        # Create admin user

        user, created = User.objects.get_or_create(
            username='django',
            first_name='User',
            last_name='Admin',
            email='test@test.test',
            is_staff=True,
            is_superuser=True,
            is_active=True
        )
        if created:
            user.save()
            user.set_password('solar')
            for group in Group.objects.all():
                user.groups.add(group)
            user.save()



import os
import json
import pkg_resources
from django.conf import settings


try:
    #  Production part
    VERSION = pkg_resources.get_distribution("django_solar").version
except pkg_resources.DistributionNotFound:
    #  Develop part
    with open(os.path.join(settings.BASE_DIR, 'package.json')) as package:
        data = json.load(package)
        VERSION = data['version']


DS_CRON_HOUR = getattr(settings, "DS_CRON_HOUR", 1)
DS_EVENT_MANAGER = getattr(settings, "DS_EVENT_MANAGER", None)
DS_SEND_MAIL = getattr(settings, "DS_SEND_MAIL", True)
